ChatDetailParams class

Constructors

ChatDetailParams(ChatConversationType conversationType, {String? conversationId, String? peerUsername, String? peerFirebaseId, List<String>? peersUsername, List<String>? peersFirebaseId, List? peersDetail, String? name, String? thumbnail, int? unread, bool isBot = false})

Properties

conversationId String?
getter/setter pair
conversationType ChatConversationType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isBot bool
getter/setter pair
name String?
getter/setter pair
peerFirebaseId String?
getter/setter pair
peersDetail List?
getter/setter pair
peersFirebaseId List<String>?
getter/setter pair
peersUsername List<String>?
getter/setter pair
peerUsername String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail String?
getter/setter pair
unread int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited