ChatDetailParams class
Constructors
-
ChatDetailParams(ChatConversationType conversationType, {String? conversationId, String? peerId, List<
String> ? peers, List? peersDetail, String? name, String? thumbnail, int? unread})
Properties
- conversationId ↔ String?
-
getter/setter pair
- conversationType ↔ ChatConversationType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- peerId ↔ String?
-
getter/setter pair
-
peers
↔ List<
String> ? -
getter/setter pair
- peersDetail ↔ List?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail ↔ String?
-
getter/setter pair
- unread ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited